pub struct SubscriptionHandle { /* private fields */ }Expand description
A handle that allows control over an active event subscription.
It can be used to pause, resume, or permanently remove a callback.
Implementations
Sourceimpl SubscriptionHandle
impl SubscriptionHandle